@@ -1,13 +1,13 @@
 # -*- coding: utf-8 -*-
 
-from level import *
-from dc import *
-from aubio_temporal import *
-from aubio_pitch import *
+from level import Level
+from dc import MeanDCShift
+from aubio_temporal import AubioTemporal
+from aubio_pitch import AubioPitch
 from aubio_mfcc import *
 from aubio_melenergy import *
 from aubio_specdesc import *
-from yaafe import * # TF : add Yaafe analyzer
+from yaafe import *
 from spectrogram import Spectrogram
 from waveform import Waveform
 from vamp_plugin import VampSimpleHost
