@@ -24,18 +24,19 @@
 from __future__ import division
 
 from timeside.core import Processor
-from timeside.__init__ import __version__
+import timeside #import __version__
 import numpy
 from collections import OrderedDict
 import h5py
 import h5tools
+
 import os
 
-if os.environ.has_key('DISPLAY'):
-    doctest_option = '+SKIP'
-else:
-    doctest_option = '+ELLIPSIS'
+if 'DISPLAY' not in os.environ:
+    import matplotlib
+    matplotlib.use('Agg')
 
+import matplotlib.pyplot as plt
 
 numpy_data_types = [
     #'float128',
@@ -382,8 +383,6 @@ class DataObject(MetadataObject):
                     all([numpy.array_equal(self[key], other[key])
                          for key in self.keys()]))
         except AttributeError:
-            # print self
-            # print [self[key] == other[key] for key in self.keys()]
             return (isinstance(other, self.__class__) and
                     all([bool(numpy.logical_and.reduce((self[key] == other[key]).ravel()))
                          for key in self.keys()]))
@@ -616,13 +615,35 @@ class AnalyzerResult(MetadataObject):
     @staticmethod
     def from_hdf5(h5group):
         # Read Sub-Group
-        result = AnalyzerResult.factory(
-                                data_mode=h5group.attrs['data_mode'],
-                                time_mode=h5group.attrs['time_mode'])
+        result = AnalyzerResult.factory(data_mode=h5group.attrs['data_mode'],
+                                        time_mode=h5group.attrs['time_mode'])
         for subgroup_name, h5subgroup in h5group.items():
             result[subgroup_name].from_hdf5(h5subgroup)
         return result
 
+    def _render_plot(self, ax):
+        return NotImplemented
+
+    def render(self, size=(1024, 256), dpi=80):
+
+        image_width, image_height = size
+
+        xSize = image_width / dpi
+        ySize = image_height / dpi
+
+        fig = plt.figure(figsize=(xSize, ySize), dpi=dpi)
+
+        ax = plt.Axes(fig, [0, 0, 1, 1])
+        ax.set_frame_on(False)
+        self._render_plot(ax)
+
+#        ax.axis('off')
+       # ax.axis('tight')
+        ax.autoscale(axis='x', tight=True)
+        fig.add_axes(ax)
+
+        return fig
+
     @property
     def data_mode(self):
         return self._data_mode
@@ -746,6 +767,9 @@ class EventObject(object):
     def duration(self):
         return numpy.zeros(len(self))
 
+    def _render_plot(self, ax):
+        ax.stem(self.time, self.data)
+
 
 class SegmentObject(EventObject):
     _time_mode = 'segment'
@@ -768,27 +792,39 @@ class GlobalLabelResult(LabelObject, GlobalObject, AnalyzerResult):
 
 
 class FrameValueResult(ValueObject, FramewiseObject, AnalyzerResult):
-    pass
+    def _render_plot(self, ax):
+        ax.plot(self.time, self.data)
 
 
 class FrameLabelResult(LabelObject, FramewiseObject, AnalyzerResult):
-    pass
+    def _render_plot(self, ax):
+        pass
 
 
 class EventValueResult(ValueObject, EventObject, AnalyzerResult):
     pass
 
-
 class EventLabelResult(LabelObject, EventObject, AnalyzerResult):
     pass
 
-
 class SegmentValueResult(ValueObject, SegmentObject, AnalyzerResult):
-    pass
+    def _render_plot(self, ax):
+        import itertools
+        colors = itertools.cycle(['b', 'g', 'r', 'c', 'm', 'y', 'k'])
+        for time, value in (self.time, self.data):
+            ax.axvline(time, ymin=0, ymax=value, color='r')
+            # TODO : check value shape !!!
 
 
 class SegmentLabelResult(LabelObject, SegmentObject, AnalyzerResult):
-    pass
+    def _render_plot(self, ax):
+        import itertools
+        colors = itertools.cycle(['b', 'g', 'r', 'c', 'm', 'y', 'k'])
+        ax_color = {}
+        for key in self.label_metadata.label.keys():
+            ax_color[key] = colors.next()
+        for time, duration, label in zip(self.time, self.duration, self.data):
+            ax.axvspan(time, time+duration, color=ax_color[label], alpha=0.3)
 
 
 class AnalyzerResultContainer(dict):
@@ -796,15 +832,15 @@ class AnalyzerResultContainer(dict):
     '''
     >>> import timeside
     >>> wavFile = 'http://github.com/yomguy/timeside-samples/raw/master/samples/sweep.mp3'
-    >>> d = timeside.decoder.FileDecoder(wavFile, start=1)
+    >>> d = timeside.decoder.FileDecoder(wavFile)
 
     >>> a = timeside.analyzer.Analyzer()
-    >>> (d|a).run() #doctest: %s
-    >>> a.new_result() #doctest: %s
-    FrameValueResult(id_metadata=IdMetadata(id='analyzer', name='Generic analyzer', unit='', description='', date='...', version='...', author='TimeSide', uuid='...'), data_object=DataObject(value=array([], dtype=float64)), audio_metadata=AudioMetadata(uri='http://...', start=1.0, duration=7..., is_segment=True, channels=None, channelsManagement=''), frame_metadata=FrameMetadata(samplerate=44100, blocksize=8192, stepsize=8192), parameters={})
+    >>> (d|a).run()
+    >>> a.new_result() #doctest: +ELLIPSIS
+    FrameValueResult(id_metadata=IdMetadata(id='analyzer', name='Generic analyzer', unit='', description='', date='...', version='...', author='TimeSide', uuid='...'), data_object=DataObject(value=array([], dtype=float64)), audio_metadata=AudioMetadata(uri='...', start=0.0, duration=8.0..., is_segment=False, channels=None, channelsManagement=''), frame_metadata=FrameMetadata(samplerate=44100, blocksize=8192, stepsize=8192), parameters={})
     >>> resContainer = timeside.analyzer.core.AnalyzerResultContainer()
+    '''
 
-    ''' % (doctest_option, doctest_option)
 
     def __init__(self, analyzer_results=None):
         super(AnalyzerResultContainer, self).__init__()
@@ -824,7 +860,7 @@ class AnalyzerResultContainer(dict):
                          analyzer_result)
         #self.results += [analyzer_result]
 
-    def to_xml(self):
+    def to_xml(self, output_file=None):
 
         import xml.etree.ElementTree as ET
         # TODO : cf. telemeta util
@@ -834,7 +870,11 @@ class AnalyzerResultContainer(dict):
             if result is not None:
                 root.append(ET.fromstring(result.to_xml()))
 
-        return ET.tostring(root, encoding="utf-8", method="xml")
+        xml_str = ET.tostring(root, encoding="utf-8", method="xml")
+        if output_file:
+            open(output_file, 'w').write(xml_str)
+        else:
+            return xml_str
 
     @staticmethod
     def from_xml(xml_string):
@@ -850,7 +890,7 @@ class AnalyzerResultContainer(dict):
 
         return results
 
-    def to_json(self):
+    def to_json(self, output_file=None):
         #if data_list == None: data_list = self.results
         import simplejson as json
 
@@ -861,8 +901,12 @@ class AnalyzerResultContainer(dict):
                         'dtype': obj.dtype.__str__()}
             raise TypeError(repr(obj) + " is not JSON serializable")
 
-        return json.dumps([res.as_dict() for res in self.values()],
-                          default=NumpyArrayEncoder)
+        json_str = json.dumps([res.as_dict() for res in self.values()],
+                              default=NumpyArrayEncoder)
+        if output_file:
+            open(output_file, 'w').write(json_str)
+        else:
+            return json_str
 
     @staticmethod
     def from_json(json_str):
@@ -890,7 +934,7 @@ class AnalyzerResultContainer(dict):
             results.add(res)
         return results
 
-    def to_yaml(self):
+    def to_yaml(self, output_file=None):
         #if data_list == None: data_list = self.results
         import yaml
 
@@ -902,7 +946,11 @@ class AnalyzerResultContainer(dict):
 
         yaml.add_representer(numpy.ndarray, numpyArray_representer)
 
-        return yaml.dump([res.as_dict() for res in self.values()])
+        yaml_str = yaml.dump([res.as_dict() for res in self.values()])
+        if output_file:
+            open(output_file, 'w').write(yaml_str)
+        else:
+            return yaml_str
 
     @staticmethod
     def from_yaml(yaml_str):
@@ -926,8 +974,11 @@ class AnalyzerResultContainer(dict):
             results.add(res)
         return results
 
-    def to_numpy(self, output_file):
-        numpy.save(output_file, self)
+    def to_numpy(self, output_file=None):
+        if output_file:
+            numpy.save(output_file, self)
+        else:
+            return self
 
     @staticmethod
     def from_numpy(input_file):
@@ -982,7 +1033,6 @@ class Analyzer(Processor):
 
     @property
     def results(self):
-
         return AnalyzerResultContainer(
             [self.process_pipe.results[key] for key in self.process_pipe.results.keys()
              if key.split('.')[0] == self.id()])
@@ -1017,12 +1067,12 @@ class Analyzer(Processor):
         from datetime import datetime
 
         result = AnalyzerResult.factory(data_mode=data_mode,
-                                time_mode=time_mode)
+                                        time_mode=time_mode)
 
         # Automatically write known metadata
         result.id_metadata.date = datetime.now().replace(
             microsecond=0).isoformat(' ')
-        result.id_metadata.version = __version__
+        result.id_metadata.version = timeside.__version__
         result.id_metadata.author = 'TimeSide'
         result.id_metadata.id = self.id()
         result.id_metadata.name = self.name()
@@ -1043,5 +1093,9 @@ class Analyzer(Processor):
 
 
 if __name__ == "__main__":
-    import doctest
-    doctest.testmod()
+    # Run doctest from __main__ and unittest from tests
+    from tests.unit_timeside import run_test_module
+    # load corresponding tests
+    from tests import test_AnalyzerResult
+
+    run_test_module([test_AnalyzerResult])
