@@ -83,7 +83,7 @@ class Processor(Component):
 
         self.parents = []
         self.source_mediainfo = None
-        self.pipe = None
+        self.process_pipe = None
         self.UUID = uuid.uuid4()
 
     @interfacedoc
@@ -247,7 +247,8 @@ class ProcessPipe(object):
         self.results = AnalyzerResultContainer()
 
     def __or__(self, other):
-        return ProcessPipe(self, other)
+        self |= other
+        return self
 
     def __ior__(self, other):
         if isinstance(other, Processor):
@@ -276,23 +277,15 @@ class ProcessPipe(object):
                 pipe += ' | '
         return pipe
 
-    def run(self, channels=None, samplerate=None, blocksize=None, stack=None):
+    def run(self, channels=None, samplerate=None, blocksize=None):
         """Setup/reset all processors in cascade and stream audio data along
-        the pipe. Also returns the pipe itself."""
+        the pipe."""
 
         source = self.processors[0]
         items = self.processors[1:]
         source.setup(channels=channels, samplerate=samplerate,
                      blocksize=blocksize)
-
-        if stack is None:
-                self.stack = False
-        else:
-            self.stack = stack
-
-        if self.stack:
-            self.frames_stack = []
-
+        source.SIG_STOP = False
         last = source
 
         # setup/reset processors and configure properties throughout the pipe
@@ -306,29 +299,30 @@ class ProcessPipe(object):
 
         # now stream audio data along the pipe
         eod = False
+
+        if source.id() == 'gst_live_dec':
+            # Set handler for Interruption signal
+            import signal
+
+            def signal_handler(signum, frame):
+                source.stop()
+
+            signal.signal(signal.SIGINT, signal_handler)
+
         while not eod:
             frames, eod = source.process()
-            if self.stack:
-                self.frames_stack.append(frames)
             for item in items:
                 frames, eod = item.process(frames, eod)
 
+        if source.id() == 'gst_live_dec':
+            # Restore default handler for Interruption signal
+            signal.signal(signal.SIGINT, signal.SIG_DFL)
+
         # Post-processing
         for item in items:
             item.post_process()
 
-        # Release processors
-        if self.stack:
-            if not isinstance(self.frames_stack, numpy.ndarray):
-                self.frames_stack = numpy.vstack(self.frames_stack)
-            from timeside.decoder.core import ArrayDecoder
-            new_source = ArrayDecoder(samples=self.frames_stack,
-                                      samplerate=source.samplerate())
-            new_source.setup(channels=source.channels(),
-                             samplerate=source.samplerate(),
-                             blocksize=source.blocksize())
-            self.processors[0] = new_source
-
+       # Release processors
         for item in items:
             item.release()
             self.processors.remove(item)
